@@ -1,3 +1,4 @@
+from incv_client.tof.mail import MailClient
 from incv_client.tof.sms import SMSClient
 from incv_client.tof.wx_robot import WXRobotClient
 
@@ -13,3 +14,7 @@ class TofClient:
     @property
     def sms(self):
         return SMSClient(self.__union)
+
+    @property
+    def mail(self):
+        return MailClient(self.__union)
